@@ -1,11 +1,3 @@
-// Copyright 2017 Serde Developers
-//
-// Licensed under the Apache License, Version 2.0 <LICENSE-APACHE or
-// http://www.apache.org/licenses/LICENSE-2.0> or the MIT license
-// <LICENSE-MIT or http://opensource.org/licenses/MIT>, at your
-// option. This file may not be copied, modified, or distributed
-// except according to those terms.
-
 //! A map of String to serde_json::Value.
 //!
 //! By default the map is backed by a [`BTreeMap`]. Enable the `preserve_order`
@@ -14,16 +6,11 @@
 //! [`BTreeMap`]: https://doc.rust-lang.org/std/collections/struct.BTreeMap.html
 //! [`IndexMap`]: https://docs.rs/indexmap/*/indexmap/map/struct.IndexMap.html
 
+use crate::lib::borrow::Borrow;
+use crate::lib::iter::FromIterator;
+use crate::lib::*;
+use crate::value::Value;
 use serde::{de, ser};
-use std::borrow::Borrow;
-use std::fmt::{self, Debug};
-use std::hash::Hash;
-use std::iter::FromIterator;
-use std::ops;
-use value::Value;
-
-#[cfg(not(feature = "preserve_order"))]
-use std::collections::{btree_map, BTreeMap};
 
 #[cfg(feature = "preserve_order")]
 use indexmap::{self, IndexMap};
@@ -117,8 +104,7 @@ impl Map<String, Value> {
     /// If the map did not have this key present, `None` is returned.
     ///
     /// If the map did have this key present, the value is updated, and the old
-    /// value is returned. The key is not updated, though; this matters for
-    /// types that can be `==` without being identical.
+    /// value is returned.
     #[inline]
     pub fn insert(&mut self, k: String, v: Value) -> Option<Value> {
         self.map.insert(k, v)
@@ -135,7 +121,21 @@ impl Map<String, Value> {
         String: Borrow<Q>,
         Q: Ord + Eq + Hash,
     {
-        self.map.remove(key)
+        #[cfg(feature = "preserve_order")]
+        return self.map.swap_remove(key);
+        #[cfg(not(feature = "preserve_order"))]
+        return self.map.remove(key);
+    }
+
+    /// Moves all elements from other into Self, leaving other empty.
+    #[inline]
+    pub fn append(&mut self, other: &mut Self) {
+        #[cfg(feature = "preserve_order")]
+        for (k, v) in std::mem::replace(&mut other.map, MapImpl::default()).into_iter() {
+            self.map.insert(k, v);
+        }
+        #[cfg(not(feature = "preserve_order"))]
+        self.map.append(&mut other.map);
     }
 
     /// Gets the given key's corresponding entry in the map for in-place
@@ -144,10 +144,10 @@ impl Map<String, Value> {
     where
         S: Into<String>,
     {
+        #[cfg(not(feature = "preserve_order"))]
+        use crate::lib::btree_map::Entry as EntryImpl;
         #[cfg(feature = "preserve_order")]
         use indexmap::map::Entry as EntryImpl;
-        #[cfg(not(feature = "preserve_order"))]
-        use std::collections::btree_map::Entry as EntryImpl;
 
         match self.map.entry(key.into()) {
             EntryImpl::Vacant(vacant) => Entry::Vacant(VacantEntry { vacant: vacant }),
@@ -245,7 +245,7 @@ impl PartialEq for Map<String, Value> {
 /// Access an element of this map. Panics if the given key is not present in the
 /// map.
 ///
-/// ```rust
+/// ```
 /// # use serde_json::Value;
 /// #
 /// # let val = &Value::String("".to_owned());
@@ -273,16 +273,13 @@ where
 /// Mutably access an element of this map. Panics if the given key is not
 /// present in the map.
 ///
-/// ```rust
-/// # #[macro_use]
-/// # extern crate serde_json;
+/// ```
+/// # use serde_json::json;
 /// #
-/// # fn main() {
-/// #     let mut map = serde_json::Map::new();
-/// #     map.insert("key".to_owned(), serde_json::Value::Null);
+/// # let mut map = serde_json::Map::new();
+/// # map.insert("key".to_owned(), serde_json::Value::Null);
 /// #
 /// map["key"] = json!("value");
-/// # }
 /// ```
 impl<'a, Q: ?Sized> ops::IndexMut<&'a Q> for Map<String, Value>
 where
@@ -308,10 +305,10 @@ impl ser::Serialize for Map<String, Value> {
         S: ser::Serializer,
     {
         use serde::ser::SerializeMap;
-        let mut map = try!(serializer.serialize_map(Some(self.len())));
+        let mut map = tri!(serializer.serialize_map(Some(self.len())));
         for (k, v) in self {
-            try!(map.serialize_key(k));
-            try!(map.serialize_value(v));
+            tri!(map.serialize_key(k));
+            tri!(map.serialize_value(v));
         }
         map.end()
     }
@@ -347,7 +344,7 @@ impl<'de> de::Deserialize<'de> for Map<String, Value> {
             {
                 let mut values = Map::new();
 
-                while let Some((key, value)) = try!(visitor.next_entry()) {
+                while let Some((key, value)) = tri!(visitor.next_entry()) {
                     values.insert(key, value);
                 }
 
@@ -452,7 +449,7 @@ impl<'a> Entry<'a> {
     ///
     /// # Examples
     ///
-    /// ```rust
+    /// ```
     /// let mut map = serde_json::Map::new();
     /// assert_eq!(map.entry("serde").key(), &"serde");
     /// ```
@@ -468,16 +465,13 @@ impl<'a> Entry<'a> {
     ///
     /// # Examples
     ///
-    /// ```rust
-    /// # #[macro_use]
-    /// # extern crate serde_json;
+    /// ```
+    /// # use serde_json::json;
     /// #
-    /// # fn main() {
     /// let mut map = serde_json::Map::new();
     /// map.entry("serde").or_insert(json!(12));
     ///
     /// assert_eq!(map["serde"], 12);
-    /// # }
     /// ```
     pub fn or_insert(self, default: Value) -> &'a mut Value {
         match self {
@@ -492,16 +486,13 @@ impl<'a> Entry<'a> {
     ///
     /// # Examples
     ///
-    /// ```rust
-    /// # #[macro_use]
-    /// # extern crate serde_json;
+    /// ```
+    /// # use serde_json::json;
     /// #
-    /// # fn main() {
     /// let mut map = serde_json::Map::new();
     /// map.entry("serde").or_insert_with(|| json!("hoho"));
     ///
     /// assert_eq!(map["serde"], "hoho".to_owned());
-    /// # }
     /// ```
     pub fn or_insert_with<F>(self, default: F) -> &'a mut Value
     where
@@ -520,7 +511,7 @@ impl<'a> VacantEntry<'a> {
     ///
     /// # Examples
     ///
-    /// ```rust
+    /// ```
     /// use serde_json::map::Entry;
     ///
     /// let mut map = serde_json::Map::new();
@@ -542,11 +533,9 @@ impl<'a> VacantEntry<'a> {
     ///
     /// # Examples
     ///
-    /// ```rust
-    /// # #[macro_use]
-    /// # extern crate serde_json;
+    /// ```
+    /// # use serde_json::json;
     /// #
-    /// # fn main() {
     /// use serde_json::map::Entry;
     ///
     /// let mut map = serde_json::Map::new();
@@ -557,7 +546,6 @@ impl<'a> VacantEntry<'a> {
     ///     }
     ///     Entry::Occupied(_) => unimplemented!(),
     /// }
-    /// # }
     /// ```
     #[inline]
     pub fn insert(self, value: Value) -> &'a mut Value {
@@ -570,11 +558,9 @@ impl<'a> OccupiedEntry<'a> {
     ///
     /// # Examples
     ///
-    /// ```rust
-    /// # #[macro_use]
-    /// # extern crate serde_json;
+    /// ```
+    /// # use serde_json::json;
     /// #
-    /// # fn main() {
     /// use serde_json::map::Entry;
     ///
     /// let mut map = serde_json::Map::new();
@@ -586,7 +572,6 @@ impl<'a> OccupiedEntry<'a> {
     ///     }
     ///     Entry::Vacant(_) => unimplemented!(),
     /// }
-    /// # }
     /// ```
     #[inline]
     pub fn key(&self) -> &String {
@@ -597,11 +582,9 @@ impl<'a> OccupiedEntry<'a> {
     ///
     /// # Examples
     ///
-    /// ```rust
-    /// # #[macro_use]
-    /// # extern crate serde_json;
+    /// ```
+    /// # use serde_json::json;
     /// #
-    /// # fn main() {
     /// use serde_json::map::Entry;
     ///
     /// let mut map = serde_json::Map::new();
@@ -613,7 +596,6 @@ impl<'a> OccupiedEntry<'a> {
     ///     }
     ///     Entry::Vacant(_) => unimplemented!(),
     /// }
-    /// # }
     /// ```
     #[inline]
     pub fn get(&self) -> &Value {
@@ -624,11 +606,9 @@ impl<'a> OccupiedEntry<'a> {
     ///
     /// # Examples
     ///
-    /// ```rust
-    /// # #[macro_use]
-    /// # extern crate serde_json;
+    /// ```
+    /// # use serde_json::json;
     /// #
-    /// # fn main() {
     /// use serde_json::map::Entry;
     ///
     /// let mut map = serde_json::Map::new();
@@ -642,7 +622,6 @@ impl<'a> OccupiedEntry<'a> {
     /// }
     ///
     /// assert_eq!(map["serde"].as_array().unwrap().len(), 4);
-    /// # }
     /// ```
     #[inline]
     pub fn get_mut(&mut self) -> &mut Value {
@@ -653,11 +632,9 @@ impl<'a> OccupiedEntry<'a> {
     ///
     /// # Examples
     ///
-    /// ```rust
-    /// # #[macro_use]
-    /// # extern crate serde_json;
+    /// ```
+    /// # use serde_json::json;
     /// #
-    /// # fn main() {
     /// use serde_json::map::Entry;
     ///
     /// let mut map = serde_json::Map::new();
@@ -671,7 +648,6 @@ impl<'a> OccupiedEntry<'a> {
     /// }
     ///
     /// assert_eq!(map["serde"].as_array().unwrap().len(), 4);
-    /// # }
     /// ```
     #[inline]
     pub fn into_mut(self) -> &'a mut Value {
@@ -683,11 +659,9 @@ impl<'a> OccupiedEntry<'a> {
     ///
     /// # Examples
     ///
-    /// ```rust
-    /// # #[macro_use]
-    /// # extern crate serde_json;
+    /// ```
+    /// # use serde_json::json;
     /// #
-    /// # fn main() {
     /// use serde_json::map::Entry;
     ///
     /// let mut map = serde_json::Map::new();
@@ -700,7 +674,6 @@ impl<'a> OccupiedEntry<'a> {
     ///     }
     ///     Entry::Vacant(_) => unimplemented!(),
     /// }
-    /// # }
     /// ```
     #[inline]
     pub fn insert(&mut self, value: Value) -> Value {
@@ -711,11 +684,9 @@ impl<'a> OccupiedEntry<'a> {
     ///
     /// # Examples
     ///
-    /// ```rust
-    /// # #[macro_use]
-    /// # extern crate serde_json;
+    /// ```
+    /// # use serde_json::json;
     /// #
-    /// # fn main() {
     /// use serde_json::map::Entry;
     ///
     /// let mut map = serde_json::Map::new();
@@ -727,11 +698,13 @@ impl<'a> OccupiedEntry<'a> {
     ///     }
     ///     Entry::Vacant(_) => unimplemented!(),
     /// }
-    /// # }
     /// ```
     #[inline]
     pub fn remove(self) -> Value {
-        self.occupied.remove()
+        #[cfg(feature = "preserve_order")]
+        return self.occupied.swap_remove();
+        #[cfg(not(feature = "preserve_order"))]
+        return self.occupied.remove();
     }
 }
 
